File package
============

Submodules
----------

File.Path module
-------------------

.. automodule:: File.Path
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: File
   :members:
   :undoc-members:
   :show-inheritance:
